@@ -15,6 +15,7 @@ describe 'mistral::keystone::auth' do
         :configure_user      => true,
         :configure_user_role => true,
         :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'mistral',
         :service_type        => 'workflowv2',
         :service_description => 'OpenStack Workflow Service',
@@ -23,7 +24,7 @@ describe 'mistral::keystone::auth' do
         :password            => 'mistral_password',
         :email               => 'mistral@localhost',
         :tenant              => 'services',
-        :roles               => ['admin'],
+        :roles               => ['admin', 'service'],
         :system_scope        => 'all',
         :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8989/v2',
@@ -38,12 +39,13 @@ describe 'mistral::keystone::auth' do
           :auth_name           => 'alt_mistral',
           :email               => 'alt_mistral@alt_localhost',
           :tenant              => 'alt_service',
-          :roles               => ['admin', 'service'],
+          :roles               => ['admin'],
           :system_scope        => 'alt_all',
           :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
+          :configure_service   => false,
           :service_description => 'Alternative OpenStack Workflow Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_workflowv2',
@@ -57,6 +59,7 @@ describe 'mistral::keystone::auth' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_workflowv2',
         :service_description => 'Alternative OpenStack Workflow Service',
@@ -65,7 +68,7 @@ describe 'mistral::keystone::auth' do
         :password            => 'mistral_password',
         :email               => 'alt_mistral@alt_localhost',
         :tenant              => 'alt_service',
-        :roles               => ['admin', 'service'],
+        :roles               => ['admin'],
         :system_scope        => 'alt_all',
         :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
